==> kubernetes-model-events-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/events/v1beta1/EventSeriesBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventSeriesBuilder extends io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluentImpl<io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesBuilder> {

    io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent;
    Boolean validationEnabled;

    public EventSeriesBuilder() {
        this(true);
    }

    public EventSeriesBuilder(Boolean validationEnabled) {
        this(new EventSeries(), validationEnabled);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent) {
        this(fluent, true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EventSeries(), validationEnabled);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance) {
        this(fluent, instance, true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCount(instance.getCount()); 
        fluent.withLastObservedTime(instance.getLastObservedTime()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance) {
        this(instance,true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCount(instance.getCount()); 
        this.withLastObservedTime(instance.getLastObservedTime()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries build() {
        EventSeries buildable = new EventSeries(fluent.getCount(),fluent.getLastObservedTime());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventSeriesBuilder that = (EventSeriesBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-events-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/events/v1beta1/EventSeriesBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventSeriesBuilder extends io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluentImpl<io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesBuilder> {

    io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent;
    Boolean validationEnabled;

    public EventSeriesBuilder() {
        this(true);
    }

    public EventSeriesBuilder(Boolean validationEnabled) {
        this(new EventSeries(), validationEnabled);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent) {
        this(fluent, true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EventSeries(), validationEnabled);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance) {
        this(fluent, instance, true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeriesFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCount(instance.getCount()); 
        fluent.withLastObservedTime(instance.getLastObservedTime()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance) {
        this(instance,true);
    }

    public EventSeriesBuilder(io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCount(instance.getCount()); 
        this.withLastObservedTime(instance.getLastObservedTime()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.events.v1beta1.EventSeries build() {
        EventSeries buildable = new EventSeries(fluent.getCount(),fluent.getLastObservedTime());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventSeriesBuilder that = (EventSeriesBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
